<template>
  <a-card :bordered="false">
    <div>
      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination=false
        :loading="loading"
        @change="handleTableChange"
      >
        <!-- :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}" -->

      </a-table>
    </div>
  </a-card>
</template>

<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { getAction, postAction } from '@/api/manage'
import JInput from '@/components/jeecg/JInput'
import Tooltip from 'ant-design-vue/es/tooltip'
import JEllipsis from "@/components/jeecg/JEllipsis";

export default {
  name: "EquipmentPrecisionParametersList",
  mixins: [JeecgListMixin],
  components: {
    JInput,
    Tooltip,
    JEllipsis,
  },
  data() {
    return {
      description: '精度参数',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: "center",
          customRender: function (t, r, index) {
            return parseInt(index) + 1;
          }
        },
        {
          title: '精度参数编码',
          dataIndex: 'num',
          align: "center",
        },
        {
          title: '精度参数名称',
          dataIndex: 'name',
          align: "center",
        },
        {
          title: '计量单位',
          dataIndex: 'unitName',
          align: "center",
        },
        {
          title: '上限值',
          dataIndex: 'upperLimit',
          align: "center",
        },
        {
          title: '下限值',
          dataIndex: 'lowerLimit',
          align: "center",
        },
        {
          title: '检定结果',
          dataIndex: 'calibrationItemResult',
          align: "center",
        },
        {
          title: '判定结果',
          dataIndex: 'judgmentResult',
          align: "center",
        },
      ],
      url: {
        list: "/eam/calibrationOrderDetail/getCalibrationOrderDetailList",
      },
      calibrationOrderId: '',
    }
  },
  watch: {
    calibrationOrderId() {
      this.queryParam = {};
      this.queryParam.calibrationOrderId = this.calibrationOrderId;
      this.loadData(1);
    },
  },
  methods: {
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error("请设置url.list属性!")
        return
      }
      if (arg === 1) {
        this.ipagination.current = 1;
      }
      var params = this.getQueryParams();//查询条件
      if (this.calibrationOrderId == '') {
        params.calibrationOrderId = '-1';
      }
      this.loading = true;
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records || res.result;
          if (res.result.total) {
            this.ipagination.total = res.result.total;
          } else {
            this.ipagination.total = 0;
          }
        } else {
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    },
  },
}
</script>

<style scoped>
@import '~@assets/less/common.less';
/deep/ .frozenRowClass {
  color: #c9c9c9;
}
.success {
  color: green;
}
.error {
  color: red;
}
.fontweight {
  font-weight: bold;
}
.ant-card {
  margin-left: -30px;
  margin-right: -30px;
}
</style>